==> estateplat-common-1.2.3-20180419.082059-65-sources.jar: cn/gtmap/estateplat/model/server/core/BdcWlxx.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * @author <a href="mailto:liaoxiang@gtmap.cn">liaoxiang</a>
 * @version V1.0, 2017/9/27
 * @description 不动产EMS物流信息表
 */
@Table(name = "bdc_wlxx")
public class BdcWlxx {
    @Id
    private String wlxxid; //物流信息id
    private String ckh; //窗口号
    private String bh; //办件编号
    private String fjr; //发件人
    private String fjrsheng; //发件人省
    private String fjrshi; //发件人市
    private String fjrqx; //发件人区县
    private String fjdz; //发件地址
    private String fjrsj; //发件人手机
    private String fjrlxdh;//发件人联系电话
    private String xflsh;//信封流水号
    private String kddh; //快递单号
    private String yjlx; //邮寄类型
    private String jjnrlx; //寄件内容类型
    private String sflx; //收费类型
    private String sjr; //收件人名称
    private String sjrsheng; //收件人省
    private String sjrshi; //收件人市
    private String sjrqx; //收件人区县
    private String sjdz; //收件地址
    private String sjrsj; //收件人手机
    private String sjrlxdh; //收件人联系电话
    private String sjryb; //收件人邮编
    private String yjclsm; //邮寄材料说明
    private String qjyzm; //取件验证码
    private String zwfwzxbm; //政务服务中心编码
    private String blbm; //办理部门
    private String blbmbm; //办理部门编码
    private Date jssj; //寄送时间
    private String sfyjjs; //是否已经寄送
    private String wllx;//物流类型
    private String proid;//项目id

    public String getWlxxid() {
        return wlxxid;
    }

    public void setWlxxid(String wlxxid) {
        this.wlxxid = wlxxid;
    }

    public String getCkh() {
        return ckh;
    }

    public void setCkh(String ckh) {
        this.ckh = ckh;
    }

    public String getBh() {
        return bh;
    }

    public void setBh(String bh) {
        this.bh = bh;
    }

    public String getFjr() {
        return fjr;
    }

    public void setFjr(String fjr) {
        this.fjr = fjr;
    }

    public String getFjrsheng() {
        return fjrsheng;
    }

    public void setFjrsheng(String fjrsheng) {
        this.fjrsheng = fjrsheng;
    }

    public String getFjrshi() {
        return fjrshi;
    }

    public void setFjrshi(String fjrshi) {
        this.fjrshi = fjrshi;
    }

    public String getFjrqx() {
        return fjrqx;
    }

    public void setFjrqx(String fjrqx) {
        this.fjrqx = fjrqx;
    }

    public String getFjdz() {
        return fjdz;
    }

    public void setFjdz(String fjdz) {
        this.fjdz = fjdz;
    }

    public String getFjrlxdh() {
        return fjrlxdh;
    }

    public void setFjrlxdh(String fjrlxdh) {
        this.fjrlxdh = fjrlxdh;
    }

    public String getFjrsj() {
        return fjrsj;
    }

    public void setFjrsj(String fjrsj) {
        this.fjrsj = fjrsj;
    }

    public String getXflsh() {
        return xflsh;
    }

    public void setXflsh(String xflsh) {
        this.xflsh = xflsh;
    }

    public String getKddh() {
        return kddh;
    }

    public void setKddh(String kddh) {
        this.kddh = kddh;
    }

    public String getYjlx() {
        return yjlx;
    }

    public void setYjlx(String yjlx) {
        this.yjlx = yjlx;
    }

    public String getJjnrlx() {
        return jjnrlx;
    }

    public void setJjnrlx(String jjnrlx) {
        this.jjnrlx = jjnrlx;
    }

    public String getSflx() {
        return sflx;
    }

    public void setSflx(String sflx) {
        this.sflx = sflx;
    }

    public String getSjrsheng() {
        return sjrsheng;
    }

    public void setSjrsheng(String sjrsheng) {
        this.sjrsheng = sjrsheng;
    }

    public String getSjr() {
        return sjr;
    }


    public void setSjr(String sjr) {
        this.sjr = sjr;
    }

    public String getSjrshi() {
        return sjrshi;
    }

    public void setSjrshi(String sjrshi) {
        this.sjrshi = sjrshi;
    }

    public String getSjrqx() {
        return sjrqx;
    }

    public void setSjrqx(String sjrqx) {
        this.sjrqx = sjrqx;
    }

    public String getSjdz() {
        return sjdz;
    }

    public void setSjdz(String sjdz) {
        this.sjdz = sjdz;
    }

    public String getSjrsj() {
        return sjrsj;
    }

    public void setSjrsj(String sjrsj) {
        this.sjrsj = sjrsj;
    }

    public String getSjrlxdh() {
        return sjrlxdh;
    }

    public void setSjrlxdh(String sjrlxdh) {
        this.sjrlxdh = sjrlxdh;
    }

    public String getSjryb() {
        return sjryb;
    }

    public void setSjryb(String sjryb) {
        this.sjryb = sjryb;
    }

    public String getYjclsm() {
        return yjclsm;
    }

    public void setYjclsm(String yjclsm) {
        this.yjclsm = yjclsm;
    }

    public String getQjyzm() {
        return qjyzm;
    }

    public void setQjyzm(String qjyzm) {
        this.qjyzm = qjyzm;
    }

    public String getZwfwzxbm() {
        return zwfwzxbm;
    }

    public void setZwfwzxbm(String zwfwzxbm) {
        this.zwfwzxbm = zwfwzxbm;
    }

    public String getBlbm() {
        return blbm;
    }

    public void setBlbm(String blbm) {
        this.blbm = blbm;
    }

    public String getBlbmbm() {
        return blbmbm;
    }

    public void setBlbmbm(String blbmbm) {
        this.blbmbm = blbmbm;
    }

    public Date getJssj() {
        return jssj;
    }

    public void setJssj(Date jssj) {
        this.jssj = jssj;
    }

    public String getSfyjjs() {
        return sfyjjs;
    }

    public void setSfyjjs(String sfyjjs) {
        this.sfyjjs = sfyjjs;
    }

    public String getWllx() {
        return wllx;
    }

    public void setWllx(String wllx) {
        this.wllx = wllx;
    }


    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }
}

==> estateplat-common-1.2.4-20211124.030600-943-sources.jar: cn/gtmap/estateplat/model/server/core/BdcWlxx.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * @author <a href="mailto:liaoxiang@gtmap.cn">liaoxiang</a>
 * @version V1.0, 2017/9/27
 * @description 不动产EMS物流信息表
 */
@Table(name = "bdc_wlxx")
public class BdcWlxx {
    @Id
    private String wlxxid; //物流信息id
    private String ckh; //窗口号
    private String bh; //办件编号
    private String fjr; //发件人
    private String fjrsheng; //发件人省
    private String fjrshi; //发件人市
    private String fjrqx; //发件人区县
    private String fjdz; //发件地址
    private String fjrsj; //发件人手机
    private String fjrlxdh;//发件人联系电话
    private String xflsh;//信封流水号
    private String kddh; //快递单号
    private String yjlx; //邮寄类型
    private String jjnrlx; //寄件内容类型
    private String sflx; //收费类型
    private String sjr; //收件人名称
    private String sjrsheng; //收件人省
    private String sjrshi; //收件人市
    private String sjrqx; //收件人区县
    private String sjdz; //收件地址
    private String sjrsj; //收件人手机
    private String sjrlxdh; //收件人联系电话
    private String sjryb; //收件人邮编
    private String yjclsm; //邮寄材料说明
    private String qjyzm; //取件验证码
    private String zwfwzxbm; //政务服务中心编码
    private String blbm; //办理部门
    private String blbmbm; //办理部门编码
    private Date jssj; //寄送时间
    private String sfyjjs; //是否已经寄送
    private String wllx;//物流类型
    private String proid;//项目id
    private String lzfsdm;//领证方式代码
    private String lzfsmc;//领证方式名称

    public String getWlxxid() {
        return wlxxid;
    }

    public void setWlxxid(String wlxxid) {
        this.wlxxid = wlxxid;
    }

    public String getCkh() {
        return ckh;
    }

    public void setCkh(String ckh) {
        this.ckh = ckh;
    }

    public String getBh() {
        return bh;
    }

    public void setBh(String bh) {
        this.bh = bh;
    }

    public String getFjr() {
        return fjr;
    }

    public void setFjr(String fjr) {
        this.fjr = fjr;
    }

    public String getFjrsheng() {
        return fjrsheng;
    }

    public void setFjrsheng(String fjrsheng) {
        this.fjrsheng = fjrsheng;
    }

    public String getFjrshi() {
        return fjrshi;
    }

    public void setFjrshi(String fjrshi) {
        this.fjrshi = fjrshi;
    }

    public String getFjrqx() {
        return fjrqx;
    }

    public void setFjrqx(String fjrqx) {
        this.fjrqx = fjrqx;
    }

    public String getFjdz() {
        return fjdz;
    }

    public void setFjdz(String fjdz) {
        this.fjdz = fjdz;
    }

    public String getFjrlxdh() {
        return fjrlxdh;
    }

    public void setFjrlxdh(String fjrlxdh) {
        this.fjrlxdh = fjrlxdh;
    }

    public String getFjrsj() {
        return fjrsj;
    }

    public void setFjrsj(String fjrsj) {
        this.fjrsj = fjrsj;
    }

    public String getXflsh() {
        return xflsh;
    }

    public void setXflsh(String xflsh) {
        this.xflsh = xflsh;
    }

    public String getKddh() {
        return kddh;
    }

    public void setKddh(String kddh) {
        this.kddh = kddh;
    }

    public String getYjlx() {
        return yjlx;
    }

    public void setYjlx(String yjlx) {
        this.yjlx = yjlx;
    }

    public String getJjnrlx() {
        return jjnrlx;
    }

    public void setJjnrlx(String jjnrlx) {
        this.jjnrlx = jjnrlx;
    }

    public String getSflx() {
        return sflx;
    }

    public void setSflx(String sflx) {
        this.sflx = sflx;
    }

    public String getSjrsheng() {
        return sjrsheng;
    }

    public void setSjrsheng(String sjrsheng) {
        this.sjrsheng = sjrsheng;
    }

    public String getSjr() {
        return sjr;
    }


    public void setSjr(String sjr) {
        this.sjr = sjr;
    }

    public String getSjrshi() {
        return sjrshi;
    }

    public void setSjrshi(String sjrshi) {
        this.sjrshi = sjrshi;
    }

    public String getSjrqx() {
        return sjrqx;
    }

    public void setSjrqx(String sjrqx) {
        this.sjrqx = sjrqx;
    }

    public String getSjdz() {
        return sjdz;
    }

    public void setSjdz(String sjdz) {
        this.sjdz = sjdz;
    }

    public String getSjrsj() {
        return sjrsj;
    }

    public void setSjrsj(String sjrsj) {
        this.sjrsj = sjrsj;
    }

    public String getSjrlxdh() {
        return sjrlxdh;
    }

    public void setSjrlxdh(String sjrlxdh) {
        this.sjrlxdh = sjrlxdh;
    }

    public String getSjryb() {
        return sjryb;
    }

    public void setSjryb(String sjryb) {
        this.sjryb = sjryb;
    }

    public String getYjclsm() {
        return yjclsm;
    }

    public void setYjclsm(String yjclsm) {
        this.yjclsm = yjclsm;
    }

    public String getQjyzm() {
        return qjyzm;
    }

    public void setQjyzm(String qjyzm) {
        this.qjyzm = qjyzm;
    }

    public String getZwfwzxbm() {
        return zwfwzxbm;
    }

    public void setZwfwzxbm(String zwfwzxbm) {
        this.zwfwzxbm = zwfwzxbm;
    }

    public String getBlbm() {
        return blbm;
    }

    public void setBlbm(String blbm) {
        this.blbm = blbm;
    }

    public String getBlbmbm() {
        return blbmbm;
    }

    public void setBlbmbm(String blbmbm) {
        this.blbmbm = blbmbm;
    }

    public Date getJssj() {
        return jssj;
    }

    public void setJssj(Date jssj) {
        this.jssj = jssj;
    }

    public String getSfyjjs() {
        return sfyjjs;
    }

    public void setSfyjjs(String sfyjjs) {
        this.sfyjjs = sfyjjs;
    }

    public String getWllx() {
        return wllx;
    }

    public void setWllx(String wllx) {
        this.wllx = wllx;
    }


    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public String getLzfsdm() {
        return lzfsdm;
    }

    public void setLzfsdm(String lzfsdm) {
        this.lzfsdm = lzfsdm;
    }

    public String getLzfsmc() {
        return lzfsmc;
    }

    public void setLzfsmc(String lzfsmc) {
        this.lzfsmc = lzfsmc;
    }
}
